# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MwsVpcEndpointArgs', 'MwsVpcEndpoint']

@pulumi.input_type
class MwsVpcEndpointArgs:
    def __init__(__self__, *,
                 vpc_endpoint_name: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_endpoint_service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_vpc_endpoint_info: Optional[pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs']] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a MwsVpcEndpoint resource.
        :param pulumi.Input[_builtins.str] vpc_endpoint_name: Name of VPC Endpoint in Databricks Account
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        :param pulumi.Input[_builtins.str] aws_endpoint_service_id: (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        :param pulumi.Input[_builtins.str] aws_vpc_endpoint_id: ID of configured aws_vpc_endpoint
        :param pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs'] gcp_vpc_endpoint_info: a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        :param pulumi.Input[_builtins.str] region: Region of AWS VPC
        :param pulumi.Input[_builtins.str] state: (AWS Only) State of VPC Endpoint
        :param pulumi.Input[_builtins.str] vpc_endpoint_id: Canonical unique identifier of VPC Endpoint in Databricks Account
        """
        pulumi.set(__self__, "vpc_endpoint_name", vpc_endpoint_name)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if aws_account_id is not None:
            pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_endpoint_service_id is not None:
            pulumi.set(__self__, "aws_endpoint_service_id", aws_endpoint_service_id)
        if aws_vpc_endpoint_id is not None:
            pulumi.set(__self__, "aws_vpc_endpoint_id", aws_vpc_endpoint_id)
        if gcp_vpc_endpoint_info is not None:
            pulumi.set(__self__, "gcp_vpc_endpoint_info", gcp_vpc_endpoint_info)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if use_case is not None:
            pulumi.set(__self__, "use_case", use_case)
        if vpc_endpoint_id is not None:
            pulumi.set(__self__, "vpc_endpoint_id", vpc_endpoint_id)

    @_builtins.property
    @pulumi.getter(name="vpcEndpointName")
    def vpc_endpoint_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of VPC Endpoint in Databricks Account
        """
        return pulumi.get(self, "vpc_endpoint_name")

    @vpc_endpoint_name.setter
    def vpc_endpoint_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "vpc_endpoint_name", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "aws_account_id")

    @aws_account_id.setter
    def aws_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsEndpointServiceId")
    def aws_endpoint_service_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        """
        return pulumi.get(self, "aws_endpoint_service_id")

    @aws_endpoint_service_id.setter
    def aws_endpoint_service_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_endpoint_service_id", value)

    @_builtins.property
    @pulumi.getter(name="awsVpcEndpointId")
    def aws_vpc_endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of configured aws_vpc_endpoint
        """
        return pulumi.get(self, "aws_vpc_endpoint_id")

    @aws_vpc_endpoint_id.setter
    def aws_vpc_endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_vpc_endpoint_id", value)

    @_builtins.property
    @pulumi.getter(name="gcpVpcEndpointInfo")
    def gcp_vpc_endpoint_info(self) -> Optional[pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs']]:
        """
        a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        """
        return pulumi.get(self, "gcp_vpc_endpoint_info")

    @gcp_vpc_endpoint_info.setter
    def gcp_vpc_endpoint_info(self, value: Optional[pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs']]):
        pulumi.set(self, "gcp_vpc_endpoint_info", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region of AWS VPC
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (AWS Only) State of VPC Endpoint
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter(name="useCase")
    def use_case(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "use_case")

    @use_case.setter
    def use_case(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "use_case", value)

    @_builtins.property
    @pulumi.getter(name="vpcEndpointId")
    def vpc_endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Canonical unique identifier of VPC Endpoint in Databricks Account
        """
        return pulumi.get(self, "vpc_endpoint_id")

    @vpc_endpoint_id.setter
    def vpc_endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_endpoint_id", value)


@pulumi.input_type
class _MwsVpcEndpointState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_endpoint_service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_vpc_endpoint_info: Optional[pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs']] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering MwsVpcEndpoint resources.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        :param pulumi.Input[_builtins.str] aws_endpoint_service_id: (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        :param pulumi.Input[_builtins.str] aws_vpc_endpoint_id: ID of configured aws_vpc_endpoint
        :param pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs'] gcp_vpc_endpoint_info: a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        :param pulumi.Input[_builtins.str] region: Region of AWS VPC
        :param pulumi.Input[_builtins.str] state: (AWS Only) State of VPC Endpoint
        :param pulumi.Input[_builtins.str] vpc_endpoint_id: Canonical unique identifier of VPC Endpoint in Databricks Account
        :param pulumi.Input[_builtins.str] vpc_endpoint_name: Name of VPC Endpoint in Databricks Account
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if aws_account_id is not None:
            pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_endpoint_service_id is not None:
            pulumi.set(__self__, "aws_endpoint_service_id", aws_endpoint_service_id)
        if aws_vpc_endpoint_id is not None:
            pulumi.set(__self__, "aws_vpc_endpoint_id", aws_vpc_endpoint_id)
        if gcp_vpc_endpoint_info is not None:
            pulumi.set(__self__, "gcp_vpc_endpoint_info", gcp_vpc_endpoint_info)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if use_case is not None:
            pulumi.set(__self__, "use_case", use_case)
        if vpc_endpoint_id is not None:
            pulumi.set(__self__, "vpc_endpoint_id", vpc_endpoint_id)
        if vpc_endpoint_name is not None:
            pulumi.set(__self__, "vpc_endpoint_name", vpc_endpoint_name)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "aws_account_id")

    @aws_account_id.setter
    def aws_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsEndpointServiceId")
    def aws_endpoint_service_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        """
        return pulumi.get(self, "aws_endpoint_service_id")

    @aws_endpoint_service_id.setter
    def aws_endpoint_service_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_endpoint_service_id", value)

    @_builtins.property
    @pulumi.getter(name="awsVpcEndpointId")
    def aws_vpc_endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of configured aws_vpc_endpoint
        """
        return pulumi.get(self, "aws_vpc_endpoint_id")

    @aws_vpc_endpoint_id.setter
    def aws_vpc_endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_vpc_endpoint_id", value)

    @_builtins.property
    @pulumi.getter(name="gcpVpcEndpointInfo")
    def gcp_vpc_endpoint_info(self) -> Optional[pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs']]:
        """
        a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        """
        return pulumi.get(self, "gcp_vpc_endpoint_info")

    @gcp_vpc_endpoint_info.setter
    def gcp_vpc_endpoint_info(self, value: Optional[pulumi.Input['MwsVpcEndpointGcpVpcEndpointInfoArgs']]):
        pulumi.set(self, "gcp_vpc_endpoint_info", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region of AWS VPC
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (AWS Only) State of VPC Endpoint
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter(name="useCase")
    def use_case(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "use_case")

    @use_case.setter
    def use_case(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "use_case", value)

    @_builtins.property
    @pulumi.getter(name="vpcEndpointId")
    def vpc_endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Canonical unique identifier of VPC Endpoint in Databricks Account
        """
        return pulumi.get(self, "vpc_endpoint_id")

    @vpc_endpoint_id.setter
    def vpc_endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_endpoint_id", value)

    @_builtins.property
    @pulumi.getter(name="vpcEndpointName")
    def vpc_endpoint_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of VPC Endpoint in Databricks Account
        """
        return pulumi.get(self, "vpc_endpoint_name")

    @vpc_endpoint_name.setter
    def vpc_endpoint_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_endpoint_name", value)


@pulumi.type_token("databricks:index/mwsVpcEndpoint:MwsVpcEndpoint")
class MwsVpcEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_endpoint_service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_vpc_endpoint_info: Optional[pulumi.Input[Union['MwsVpcEndpointGcpVpcEndpointInfoArgs', 'MwsVpcEndpointGcpVpcEndpointInfoArgsDict']]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Enables you to register aws_vpc_endpoint resources or gcp vpc_endpoint resources with Databricks such that they can be used as part of a MwsNetworks configuration.

        > This resource can only be used with an account-level provider!

        It is strongly recommended that customers read the [Enable AWS Private Link](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html) or the [Enable GCP Private Service Connect](https://docs.gcp.databricks.com/administration-guide/cloud-configurations/gcp/private-service-connect.html) documentation before trying to leverage this resource.

        ## Example Usage

        ### Databricks on AWS usage

        Before using this resource, you will need to create the necessary VPC Endpoints as per your [VPC endpoint requirements](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#vpc-endpoint-requirements). You can use the aws_vpc_endpoint resource for this, for example:

        ```python
        import pulumi
        import pulumi_aws as aws

        workspace = aws.index.VpcEndpoint("workspace",
            vpc_id=vpc.vpc_id,
            service_name=private_link.workspace_service,
            vpc_endpoint_type=Interface,
            security_group_ids=[vpc.default_security_group_id],
            subnet_ids=[pl_subnet.id],
            private_dns_enabled=True,
            opts = pulumi.ResourceOptions(depends_on=[pl_subnet]))
        relay = aws.index.VpcEndpoint("relay",
            vpc_id=vpc.vpc_id,
            service_name=private_link.relay_service,
            vpc_endpoint_type=Interface,
            security_group_ids=[vpc.default_security_group_id],
            subnet_ids=[pl_subnet.id],
            private_dns_enabled=True,
            opts = pulumi.ResourceOptions(depends_on=[pl_subnet]))
        ```

        Depending on your use case, you may need or choose to add VPC Endpoints for the AWS Services Databricks uses. See [Add VPC endpoints for other AWS services (recommended but optional)
        ](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#step-9-add-vpc-endpoints-for-other-aws-services-recommended-but-optional) for more information. For example:

        ```python
        import pulumi
        import pulumi_aws as aws

        s3 = aws.index.VpcEndpoint("s3",
            vpc_id=vpc.vpc_id,
            route_table_ids=vpc.private_route_table_ids,
            service_name=fcom.amazonaws.{region}.s3,
            opts = pulumi.ResourceOptions(depends_on=[vpc]))
        sts = aws.index.VpcEndpoint("sts",
            vpc_id=vpc.vpc_id,
            service_name=fcom.amazonaws.{region}.sts,
            vpc_endpoint_type=Interface,
            subnet_ids=vpc.private_subnets,
            security_group_ids=[vpc.default_security_group_id],
            private_dns_enabled=True,
            opts = pulumi.ResourceOptions(depends_on=[vpc]))
        kinesis_streams = aws.index.VpcEndpoint("kinesis-streams",
            vpc_id=vpc.vpc_id,
            service_name=fcom.amazonaws.{region}.kinesis-streams,
            vpc_endpoint_type=Interface,
            subnet_ids=vpc.private_subnets,
            security_group_ids=[vpc.default_security_group_id],
            opts = pulumi.ResourceOptions(depends_on=[vpc]))
        ```

        Once you have created the necessary endpoints, you need to register each of them via *this* Pulumi resource, which calls out to the [Databricks Account API](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#step-3-register-your-vpc-endpoint-ids-with-the-account-api)):

        ```python
        import pulumi
        import pulumi_databricks as databricks

        workspace = databricks.MwsVpcEndpoint("workspace",
            account_id=databricks_account_id,
            aws_vpc_endpoint_id=workspace_aws_vpc_endpoint["id"],
            vpc_endpoint_name=f"VPC Relay for {vpc['vpcId']}",
            region=region,
            opts = pulumi.ResourceOptions(depends_on=[workspace_aws_vpc_endpoint]))
        relay = databricks.MwsVpcEndpoint("relay",
            account_id=databricks_account_id,
            aws_vpc_endpoint_id=relay_aws_vpc_endpoint["id"],
            vpc_endpoint_name=f"VPC Relay for {vpc['vpcId']}",
            region=region,
            opts = pulumi.ResourceOptions(depends_on=[relay_aws_vpc_endpoint]))
        ```

        Typically the next steps after this would be to create a MwsPrivateAccessSettings and MwsNetworks configuration, before passing the `databricks_mws_private_access_settings.pas.private_access_settings_id` and `databricks_mws_networks.this.network_id` into a MwsWorkspaces resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.MwsWorkspaces("this",
            account_id=databricks_account_id,
            aws_region=region,
            workspace_name=prefix,
            credentials_id=this_databricks_mws_credentials["credentialsId"],
            storage_configuration_id=this_databricks_mws_storage_configurations["storageConfigurationId"],
            network_id=this_databricks_mws_networks["networkId"],
            private_access_settings_id=pas["privateAccessSettingsId"],
            pricing_tier="ENTERPRISE",
            opts = pulumi.ResourceOptions(depends_on=[this_databricks_mws_networks]))
        ```

        ### Databricks on GCP usage

        Before using this resource, you will need to create the necessary Private Service Connect (PSC) connections on your Google Cloud VPC networks. You can see [Enable Private Service Connect for your workspace](https://docs.gcp.databricks.com/administration-guide/cloud-configurations/gcp/private-service-connect.html) for more details.

        Once you have created the necessary PSC connections, you need to register each of them via *this* Pulumi resource, which calls out to the Databricks Account API.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in https://accounts.gcp.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        databricks_google_service_account = config.require_object("databricksGoogleServiceAccount")
        google_project = config.require_object("googleProject")
        subnet_region = config.require_object("subnetRegion")
        workspace = databricks.MwsVpcEndpoint("workspace",
            account_id=databricks_account_id,
            vpc_endpoint_name="PSC Rest API endpoint",
            gcp_vpc_endpoint_info={
                "project_id": google_project,
                "psc_endpoint_name": "PSC Rest API endpoint",
                "endpoint_region": subnet_region,
            })
        relay = databricks.MwsVpcEndpoint("relay",
            account_id=databricks_account_id,
            vpc_endpoint_name="PSC Relay endpoint",
            gcp_vpc_endpoint_info={
                "project_id": google_project,
                "psc_endpoint_name": "PSC Relay endpoint",
                "endpoint_region": subnet_region,
            })
        ```

        Typically the next steps after this would be to create a MwsPrivateAccessSettings and MwsNetworks configuration, before passing the `databricks_mws_private_access_settings.pas.private_access_settings_id` and `databricks_mws_networks.this.network_id` into a MwsWorkspaces resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.MwsWorkspaces("this",
            account_id=databricks_account_id,
            workspace_name="gcp workspace",
            location=subnet_region,
            cloud_resource_container={
                "gcp": {
                    "project_id": google_project,
                },
            },
            gke_config={
                "connectivity_type": "PRIVATE_NODE_PUBLIC_MASTER",
                "master_ip_range": "10.3.0.0/28",
            },
            network_id=this_databricks_mws_networks["networkId"],
            private_access_settings_id=pas["privateAccessSettingsId"],
            pricing_tier="PREMIUM",
            opts = pulumi.ResourceOptions(depends_on=[this_databricks_mws_networks]))
        ```

        ## Related Resources

        The following resources are used in the same context:

        * Provisioning Databricks on AWS guide.
        * Provisioning Databricks on AWS with Private Link guide.
        * Provisioning AWS Databricks workspaces with a Hub & Spoke firewall for data exfiltration protection guide.
        * Provisioning Databricks workspaces on GCP with Private Service Connect guide.
        * MwsNetworks to [configure VPC](https://docs.databricks.com/administration-guide/cloud-configurations/aws/customer-managed-vpc.html) & subnets for new workspaces within AWS.
        * MwsPrivateAccessSettings to create a [Private Access Setting](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#step-5-create-a-private-access-settings-configuration-using-the-databricks-account-api) that can be used as part of a MwsWorkspaces resource to create a [Databricks Workspace that leverages AWS Private Link](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html).
        * MwsWorkspaces to set up [AWS and GCP workspaces](https://docs.databricks.com/getting-started/overview.html#e2-architecture-1).

        ## Import

        > Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        :param pulumi.Input[_builtins.str] aws_endpoint_service_id: (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        :param pulumi.Input[_builtins.str] aws_vpc_endpoint_id: ID of configured aws_vpc_endpoint
        :param pulumi.Input[Union['MwsVpcEndpointGcpVpcEndpointInfoArgs', 'MwsVpcEndpointGcpVpcEndpointInfoArgsDict']] gcp_vpc_endpoint_info: a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        :param pulumi.Input[_builtins.str] region: Region of AWS VPC
        :param pulumi.Input[_builtins.str] state: (AWS Only) State of VPC Endpoint
        :param pulumi.Input[_builtins.str] vpc_endpoint_id: Canonical unique identifier of VPC Endpoint in Databricks Account
        :param pulumi.Input[_builtins.str] vpc_endpoint_name: Name of VPC Endpoint in Databricks Account
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MwsVpcEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Enables you to register aws_vpc_endpoint resources or gcp vpc_endpoint resources with Databricks such that they can be used as part of a MwsNetworks configuration.

        > This resource can only be used with an account-level provider!

        It is strongly recommended that customers read the [Enable AWS Private Link](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html) or the [Enable GCP Private Service Connect](https://docs.gcp.databricks.com/administration-guide/cloud-configurations/gcp/private-service-connect.html) documentation before trying to leverage this resource.

        ## Example Usage

        ### Databricks on AWS usage

        Before using this resource, you will need to create the necessary VPC Endpoints as per your [VPC endpoint requirements](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#vpc-endpoint-requirements). You can use the aws_vpc_endpoint resource for this, for example:

        ```python
        import pulumi
        import pulumi_aws as aws

        workspace = aws.index.VpcEndpoint("workspace",
            vpc_id=vpc.vpc_id,
            service_name=private_link.workspace_service,
            vpc_endpoint_type=Interface,
            security_group_ids=[vpc.default_security_group_id],
            subnet_ids=[pl_subnet.id],
            private_dns_enabled=True,
            opts = pulumi.ResourceOptions(depends_on=[pl_subnet]))
        relay = aws.index.VpcEndpoint("relay",
            vpc_id=vpc.vpc_id,
            service_name=private_link.relay_service,
            vpc_endpoint_type=Interface,
            security_group_ids=[vpc.default_security_group_id],
            subnet_ids=[pl_subnet.id],
            private_dns_enabled=True,
            opts = pulumi.ResourceOptions(depends_on=[pl_subnet]))
        ```

        Depending on your use case, you may need or choose to add VPC Endpoints for the AWS Services Databricks uses. See [Add VPC endpoints for other AWS services (recommended but optional)
        ](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#step-9-add-vpc-endpoints-for-other-aws-services-recommended-but-optional) for more information. For example:

        ```python
        import pulumi
        import pulumi_aws as aws

        s3 = aws.index.VpcEndpoint("s3",
            vpc_id=vpc.vpc_id,
            route_table_ids=vpc.private_route_table_ids,
            service_name=fcom.amazonaws.{region}.s3,
            opts = pulumi.ResourceOptions(depends_on=[vpc]))
        sts = aws.index.VpcEndpoint("sts",
            vpc_id=vpc.vpc_id,
            service_name=fcom.amazonaws.{region}.sts,
            vpc_endpoint_type=Interface,
            subnet_ids=vpc.private_subnets,
            security_group_ids=[vpc.default_security_group_id],
            private_dns_enabled=True,
            opts = pulumi.ResourceOptions(depends_on=[vpc]))
        kinesis_streams = aws.index.VpcEndpoint("kinesis-streams",
            vpc_id=vpc.vpc_id,
            service_name=fcom.amazonaws.{region}.kinesis-streams,
            vpc_endpoint_type=Interface,
            subnet_ids=vpc.private_subnets,
            security_group_ids=[vpc.default_security_group_id],
            opts = pulumi.ResourceOptions(depends_on=[vpc]))
        ```

        Once you have created the necessary endpoints, you need to register each of them via *this* Pulumi resource, which calls out to the [Databricks Account API](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#step-3-register-your-vpc-endpoint-ids-with-the-account-api)):

        ```python
        import pulumi
        import pulumi_databricks as databricks

        workspace = databricks.MwsVpcEndpoint("workspace",
            account_id=databricks_account_id,
            aws_vpc_endpoint_id=workspace_aws_vpc_endpoint["id"],
            vpc_endpoint_name=f"VPC Relay for {vpc['vpcId']}",
            region=region,
            opts = pulumi.ResourceOptions(depends_on=[workspace_aws_vpc_endpoint]))
        relay = databricks.MwsVpcEndpoint("relay",
            account_id=databricks_account_id,
            aws_vpc_endpoint_id=relay_aws_vpc_endpoint["id"],
            vpc_endpoint_name=f"VPC Relay for {vpc['vpcId']}",
            region=region,
            opts = pulumi.ResourceOptions(depends_on=[relay_aws_vpc_endpoint]))
        ```

        Typically the next steps after this would be to create a MwsPrivateAccessSettings and MwsNetworks configuration, before passing the `databricks_mws_private_access_settings.pas.private_access_settings_id` and `databricks_mws_networks.this.network_id` into a MwsWorkspaces resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.MwsWorkspaces("this",
            account_id=databricks_account_id,
            aws_region=region,
            workspace_name=prefix,
            credentials_id=this_databricks_mws_credentials["credentialsId"],
            storage_configuration_id=this_databricks_mws_storage_configurations["storageConfigurationId"],
            network_id=this_databricks_mws_networks["networkId"],
            private_access_settings_id=pas["privateAccessSettingsId"],
            pricing_tier="ENTERPRISE",
            opts = pulumi.ResourceOptions(depends_on=[this_databricks_mws_networks]))
        ```

        ### Databricks on GCP usage

        Before using this resource, you will need to create the necessary Private Service Connect (PSC) connections on your Google Cloud VPC networks. You can see [Enable Private Service Connect for your workspace](https://docs.gcp.databricks.com/administration-guide/cloud-configurations/gcp/private-service-connect.html) for more details.

        Once you have created the necessary PSC connections, you need to register each of them via *this* Pulumi resource, which calls out to the Databricks Account API.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in https://accounts.gcp.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        databricks_google_service_account = config.require_object("databricksGoogleServiceAccount")
        google_project = config.require_object("googleProject")
        subnet_region = config.require_object("subnetRegion")
        workspace = databricks.MwsVpcEndpoint("workspace",
            account_id=databricks_account_id,
            vpc_endpoint_name="PSC Rest API endpoint",
            gcp_vpc_endpoint_info={
                "project_id": google_project,
                "psc_endpoint_name": "PSC Rest API endpoint",
                "endpoint_region": subnet_region,
            })
        relay = databricks.MwsVpcEndpoint("relay",
            account_id=databricks_account_id,
            vpc_endpoint_name="PSC Relay endpoint",
            gcp_vpc_endpoint_info={
                "project_id": google_project,
                "psc_endpoint_name": "PSC Relay endpoint",
                "endpoint_region": subnet_region,
            })
        ```

        Typically the next steps after this would be to create a MwsPrivateAccessSettings and MwsNetworks configuration, before passing the `databricks_mws_private_access_settings.pas.private_access_settings_id` and `databricks_mws_networks.this.network_id` into a MwsWorkspaces resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.MwsWorkspaces("this",
            account_id=databricks_account_id,
            workspace_name="gcp workspace",
            location=subnet_region,
            cloud_resource_container={
                "gcp": {
                    "project_id": google_project,
                },
            },
            gke_config={
                "connectivity_type": "PRIVATE_NODE_PUBLIC_MASTER",
                "master_ip_range": "10.3.0.0/28",
            },
            network_id=this_databricks_mws_networks["networkId"],
            private_access_settings_id=pas["privateAccessSettingsId"],
            pricing_tier="PREMIUM",
            opts = pulumi.ResourceOptions(depends_on=[this_databricks_mws_networks]))
        ```

        ## Related Resources

        The following resources are used in the same context:

        * Provisioning Databricks on AWS guide.
        * Provisioning Databricks on AWS with Private Link guide.
        * Provisioning AWS Databricks workspaces with a Hub & Spoke firewall for data exfiltration protection guide.
        * Provisioning Databricks workspaces on GCP with Private Service Connect guide.
        * MwsNetworks to [configure VPC](https://docs.databricks.com/administration-guide/cloud-configurations/aws/customer-managed-vpc.html) & subnets for new workspaces within AWS.
        * MwsPrivateAccessSettings to create a [Private Access Setting](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html#step-5-create-a-private-access-settings-configuration-using-the-databricks-account-api) that can be used as part of a MwsWorkspaces resource to create a [Databricks Workspace that leverages AWS Private Link](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html).
        * MwsWorkspaces to set up [AWS and GCP workspaces](https://docs.databricks.com/getting-started/overview.html#e2-architecture-1).

        ## Import

        > Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param MwsVpcEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MwsVpcEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_endpoint_service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 gcp_vpc_endpoint_info: Optional[pulumi.Input[Union['MwsVpcEndpointGcpVpcEndpointInfoArgs', 'MwsVpcEndpointGcpVpcEndpointInfoArgsDict']]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MwsVpcEndpointArgs.__new__(MwsVpcEndpointArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["aws_account_id"] = aws_account_id
            __props__.__dict__["aws_endpoint_service_id"] = aws_endpoint_service_id
            __props__.__dict__["aws_vpc_endpoint_id"] = aws_vpc_endpoint_id
            __props__.__dict__["gcp_vpc_endpoint_info"] = gcp_vpc_endpoint_info
            __props__.__dict__["region"] = region
            __props__.__dict__["state"] = state
            __props__.__dict__["use_case"] = use_case
            __props__.__dict__["vpc_endpoint_id"] = vpc_endpoint_id
            if vpc_endpoint_name is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_endpoint_name'")
            __props__.__dict__["vpc_endpoint_name"] = vpc_endpoint_name
        super(MwsVpcEndpoint, __self__).__init__(
            'databricks:index/mwsVpcEndpoint:MwsVpcEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
            aws_endpoint_service_id: Optional[pulumi.Input[_builtins.str]] = None,
            aws_vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
            gcp_vpc_endpoint_info: Optional[pulumi.Input[Union['MwsVpcEndpointGcpVpcEndpointInfoArgs', 'MwsVpcEndpointGcpVpcEndpointInfoArgsDict']]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            use_case: Optional[pulumi.Input[_builtins.str]] = None,
            vpc_endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
            vpc_endpoint_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'MwsVpcEndpoint':
        """
        Get an existing MwsVpcEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        :param pulumi.Input[_builtins.str] aws_endpoint_service_id: (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        :param pulumi.Input[_builtins.str] aws_vpc_endpoint_id: ID of configured aws_vpc_endpoint
        :param pulumi.Input[Union['MwsVpcEndpointGcpVpcEndpointInfoArgs', 'MwsVpcEndpointGcpVpcEndpointInfoArgsDict']] gcp_vpc_endpoint_info: a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        :param pulumi.Input[_builtins.str] region: Region of AWS VPC
        :param pulumi.Input[_builtins.str] state: (AWS Only) State of VPC Endpoint
        :param pulumi.Input[_builtins.str] vpc_endpoint_id: Canonical unique identifier of VPC Endpoint in Databricks Account
        :param pulumi.Input[_builtins.str] vpc_endpoint_name: Name of VPC Endpoint in Databricks Account
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MwsVpcEndpointState.__new__(_MwsVpcEndpointState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["aws_account_id"] = aws_account_id
        __props__.__dict__["aws_endpoint_service_id"] = aws_endpoint_service_id
        __props__.__dict__["aws_vpc_endpoint_id"] = aws_vpc_endpoint_id
        __props__.__dict__["gcp_vpc_endpoint_info"] = gcp_vpc_endpoint_info
        __props__.__dict__["region"] = region
        __props__.__dict__["state"] = state
        __props__.__dict__["use_case"] = use_case
        __props__.__dict__["vpc_endpoint_id"] = vpc_endpoint_id
        __props__.__dict__["vpc_endpoint_name"] = vpc_endpoint_name
        return MwsVpcEndpoint(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Account Id that could be found in the Accounts Console for [AWS](https://accounts.cloud.databricks.com/) or [GCP](https://accounts.gcp.databricks.com/)
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "aws_account_id")

    @_builtins.property
    @pulumi.getter(name="awsEndpointServiceId")
    def aws_endpoint_service_id(self) -> pulumi.Output[_builtins.str]:
        """
        (AWS Only) The ID of the Databricks endpoint service that this VPC endpoint is connected to. Please find the list of endpoint service IDs for each supported region in the [Databricks PrivateLink documentation](https://docs.databricks.com/administration-guide/cloud-configurations/aws/privatelink.html)
        """
        return pulumi.get(self, "aws_endpoint_service_id")

    @_builtins.property
    @pulumi.getter(name="awsVpcEndpointId")
    def aws_vpc_endpoint_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of configured aws_vpc_endpoint
        """
        return pulumi.get(self, "aws_vpc_endpoint_id")

    @_builtins.property
    @pulumi.getter(name="gcpVpcEndpointInfo")
    def gcp_vpc_endpoint_info(self) -> pulumi.Output[Optional['outputs.MwsVpcEndpointGcpVpcEndpointInfo']]:
        """
        a block consists of Google Cloud specific information for this PSC endpoint. It has the following fields:
        """
        return pulumi.get(self, "gcp_vpc_endpoint_info")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Region of AWS VPC
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (AWS Only) State of VPC Endpoint
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="useCase")
    def use_case(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "use_case")

    @_builtins.property
    @pulumi.getter(name="vpcEndpointId")
    def vpc_endpoint_id(self) -> pulumi.Output[_builtins.str]:
        """
        Canonical unique identifier of VPC Endpoint in Databricks Account
        """
        return pulumi.get(self, "vpc_endpoint_id")

    @_builtins.property
    @pulumi.getter(name="vpcEndpointName")
    def vpc_endpoint_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of VPC Endpoint in Databricks Account
        """
        return pulumi.get(self, "vpc_endpoint_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['MetastoreArgs', 'Metastore']

@pulumi.input_type
class MetastoreArgs:
    def __init__(__self__, *,
                 default_data_access_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_recipient_token_lifetime_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 delta_sharing_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 external_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege_model_version: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Metastore resource.
        :param pulumi.Input[_builtins.str] default_data_access_config_id: (Optional) Unique identifier of the metastore's default data access configuration.
        :param pulumi.Input[_builtins.str] delta_sharing_organization_name: The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        :param pulumi.Input[_builtins.int] delta_sharing_recipient_token_lifetime_in_seconds: Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        :param pulumi.Input[_builtins.str] delta_sharing_scope: Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        :param pulumi.Input[_builtins.bool] external_access_enabled: Whether to allow non-DBR clients to directly access entities under the metastore.
        :param pulumi.Input[_builtins.bool] force_destroy: Destroy metastore regardless of its contents.
        :param pulumi.Input[_builtins.str] name: Name of metastore.
        :param pulumi.Input[_builtins.str] owner: Username/groupname/sp application_id of the metastore owner.
        :param pulumi.Input[_builtins.str] privilege_model_version: Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        :param pulumi.Input[_builtins.str] region: The region of the metastore
        :param pulumi.Input[_builtins.str] storage_root: Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        :param pulumi.Input[_builtins.str] storage_root_credential_id: (Optional) UUID of storage credential to access the metastore storage_root.
        :param pulumi.Input[_builtins.str] storage_root_credential_name: Name of the storage credential to access the metastore storage_root.
        """
        if default_data_access_config_id is not None:
            pulumi.set(__self__, "default_data_access_config_id", default_data_access_config_id)
        if delta_sharing_organization_name is not None:
            pulumi.set(__self__, "delta_sharing_organization_name", delta_sharing_organization_name)
        if delta_sharing_recipient_token_lifetime_in_seconds is not None:
            pulumi.set(__self__, "delta_sharing_recipient_token_lifetime_in_seconds", delta_sharing_recipient_token_lifetime_in_seconds)
        if delta_sharing_scope is not None:
            pulumi.set(__self__, "delta_sharing_scope", delta_sharing_scope)
        if external_access_enabled is not None:
            pulumi.set(__self__, "external_access_enabled", external_access_enabled)
        if force_destroy is not None:
            pulumi.set(__self__, "force_destroy", force_destroy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if privilege_model_version is not None:
            pulumi.set(__self__, "privilege_model_version", privilege_model_version)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if storage_root is not None:
            pulumi.set(__self__, "storage_root", storage_root)
        if storage_root_credential_id is not None:
            pulumi.set(__self__, "storage_root_credential_id", storage_root_credential_id)
        if storage_root_credential_name is not None:
            pulumi.set(__self__, "storage_root_credential_name", storage_root_credential_name)

    @_builtins.property
    @pulumi.getter(name="defaultDataAccessConfigId")
    def default_data_access_config_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional) Unique identifier of the metastore's default data access configuration.
        """
        return pulumi.get(self, "default_data_access_config_id")

    @default_data_access_config_id.setter
    def default_data_access_config_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_data_access_config_id", value)

    @_builtins.property
    @pulumi.getter(name="deltaSharingOrganizationName")
    def delta_sharing_organization_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        """
        return pulumi.get(self, "delta_sharing_organization_name")

    @delta_sharing_organization_name.setter
    def delta_sharing_organization_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delta_sharing_organization_name", value)

    @_builtins.property
    @pulumi.getter(name="deltaSharingRecipientTokenLifetimeInSeconds")
    def delta_sharing_recipient_token_lifetime_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        """
        return pulumi.get(self, "delta_sharing_recipient_token_lifetime_in_seconds")

    @delta_sharing_recipient_token_lifetime_in_seconds.setter
    def delta_sharing_recipient_token_lifetime_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "delta_sharing_recipient_token_lifetime_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="deltaSharingScope")
    def delta_sharing_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        """
        return pulumi.get(self, "delta_sharing_scope")

    @delta_sharing_scope.setter
    def delta_sharing_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delta_sharing_scope", value)

    @_builtins.property
    @pulumi.getter(name="externalAccessEnabled")
    def external_access_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to allow non-DBR clients to directly access entities under the metastore.
        """
        return pulumi.get(self, "external_access_enabled")

    @external_access_enabled.setter
    def external_access_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "external_access_enabled", value)

    @_builtins.property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Destroy metastore regardless of its contents.
        """
        return pulumi.get(self, "force_destroy")

    @force_destroy.setter
    def force_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_destroy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of metastore.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username/groupname/sp application_id of the metastore owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="privilegeModelVersion")
    def privilege_model_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        """
        return pulumi.get(self, "privilege_model_version")

    @privilege_model_version.setter
    def privilege_model_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privilege_model_version", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region of the metastore
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        """
        return pulumi.get(self, "storage_root")

    @storage_root.setter
    def storage_root(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root", value)

    @_builtins.property
    @pulumi.getter(name="storageRootCredentialId")
    def storage_root_credential_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional) UUID of storage credential to access the metastore storage_root.
        """
        return pulumi.get(self, "storage_root_credential_id")

    @storage_root_credential_id.setter
    def storage_root_credential_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root_credential_id", value)

    @_builtins.property
    @pulumi.getter(name="storageRootCredentialName")
    def storage_root_credential_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the storage credential to access the metastore storage_root.
        """
        return pulumi.get(self, "storage_root_credential_name")

    @storage_root_credential_name.setter
    def storage_root_credential_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root_credential_name", value)


@pulumi.input_type
class _MetastoreState:
    def __init__(__self__, *,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 default_data_access_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_recipient_token_lifetime_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 delta_sharing_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 external_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 global_metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege_model_version: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Metastore resources.
        :param pulumi.Input[_builtins.str] cloud: Cloud vendor of the metastore home shard (e.g., `aws`, `azure`, `gcp`).
        :param pulumi.Input[_builtins.int] created_at: Time at which the metastore was created, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] created_by: Username of metastore creator.
        :param pulumi.Input[_builtins.str] default_data_access_config_id: (Optional) Unique identifier of the metastore's default data access configuration.
        :param pulumi.Input[_builtins.str] delta_sharing_organization_name: The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        :param pulumi.Input[_builtins.int] delta_sharing_recipient_token_lifetime_in_seconds: Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        :param pulumi.Input[_builtins.str] delta_sharing_scope: Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        :param pulumi.Input[_builtins.bool] external_access_enabled: Whether to allow non-DBR clients to directly access entities under the metastore.
        :param pulumi.Input[_builtins.bool] force_destroy: Destroy metastore regardless of its contents.
        :param pulumi.Input[_builtins.str] global_metastore_id: Globally unique metastore ID across clouds and regions, of the form `cloud:region:metastore_id`.
        :param pulumi.Input[_builtins.str] metastore_id: Unique identifier of the metastore.
        :param pulumi.Input[_builtins.str] name: Name of metastore.
        :param pulumi.Input[_builtins.str] owner: Username/groupname/sp application_id of the metastore owner.
        :param pulumi.Input[_builtins.str] privilege_model_version: Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        :param pulumi.Input[_builtins.str] region: The region of the metastore
        :param pulumi.Input[_builtins.str] storage_root: Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        :param pulumi.Input[_builtins.str] storage_root_credential_id: (Optional) UUID of storage credential to access the metastore storage_root.
        :param pulumi.Input[_builtins.str] storage_root_credential_name: Name of the storage credential to access the metastore storage_root.
        :param pulumi.Input[_builtins.int] updated_at: Time at which the metastore was last modified, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] updated_by: Username of user who last modified the metastore.
        """
        if cloud is not None:
            pulumi.set(__self__, "cloud", cloud)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if default_data_access_config_id is not None:
            pulumi.set(__self__, "default_data_access_config_id", default_data_access_config_id)
        if delta_sharing_organization_name is not None:
            pulumi.set(__self__, "delta_sharing_organization_name", delta_sharing_organization_name)
        if delta_sharing_recipient_token_lifetime_in_seconds is not None:
            pulumi.set(__self__, "delta_sharing_recipient_token_lifetime_in_seconds", delta_sharing_recipient_token_lifetime_in_seconds)
        if delta_sharing_scope is not None:
            pulumi.set(__self__, "delta_sharing_scope", delta_sharing_scope)
        if external_access_enabled is not None:
            pulumi.set(__self__, "external_access_enabled", external_access_enabled)
        if force_destroy is not None:
            pulumi.set(__self__, "force_destroy", force_destroy)
        if global_metastore_id is not None:
            pulumi.set(__self__, "global_metastore_id", global_metastore_id)
        if metastore_id is not None:
            pulumi.set(__self__, "metastore_id", metastore_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if privilege_model_version is not None:
            pulumi.set(__self__, "privilege_model_version", privilege_model_version)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if storage_root is not None:
            pulumi.set(__self__, "storage_root", storage_root)
        if storage_root_credential_id is not None:
            pulumi.set(__self__, "storage_root_credential_id", storage_root_credential_id)
        if storage_root_credential_name is not None:
            pulumi.set(__self__, "storage_root_credential_name", storage_root_credential_name)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Cloud vendor of the metastore home shard (e.g., `aws`, `azure`, `gcp`).
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time at which the metastore was created, in epoch milliseconds.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username of metastore creator.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="defaultDataAccessConfigId")
    def default_data_access_config_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional) Unique identifier of the metastore's default data access configuration.
        """
        return pulumi.get(self, "default_data_access_config_id")

    @default_data_access_config_id.setter
    def default_data_access_config_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_data_access_config_id", value)

    @_builtins.property
    @pulumi.getter(name="deltaSharingOrganizationName")
    def delta_sharing_organization_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        """
        return pulumi.get(self, "delta_sharing_organization_name")

    @delta_sharing_organization_name.setter
    def delta_sharing_organization_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delta_sharing_organization_name", value)

    @_builtins.property
    @pulumi.getter(name="deltaSharingRecipientTokenLifetimeInSeconds")
    def delta_sharing_recipient_token_lifetime_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        """
        return pulumi.get(self, "delta_sharing_recipient_token_lifetime_in_seconds")

    @delta_sharing_recipient_token_lifetime_in_seconds.setter
    def delta_sharing_recipient_token_lifetime_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "delta_sharing_recipient_token_lifetime_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="deltaSharingScope")
    def delta_sharing_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        """
        return pulumi.get(self, "delta_sharing_scope")

    @delta_sharing_scope.setter
    def delta_sharing_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delta_sharing_scope", value)

    @_builtins.property
    @pulumi.getter(name="externalAccessEnabled")
    def external_access_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to allow non-DBR clients to directly access entities under the metastore.
        """
        return pulumi.get(self, "external_access_enabled")

    @external_access_enabled.setter
    def external_access_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "external_access_enabled", value)

    @_builtins.property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Destroy metastore regardless of its contents.
        """
        return pulumi.get(self, "force_destroy")

    @force_destroy.setter
    def force_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_destroy", value)

    @_builtins.property
    @pulumi.getter(name="globalMetastoreId")
    def global_metastore_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Globally unique metastore ID across clouds and regions, of the form `cloud:region:metastore_id`.
        """
        return pulumi.get(self, "global_metastore_id")

    @global_metastore_id.setter
    def global_metastore_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "global_metastore_id", value)

    @_builtins.property
    @pulumi.getter(name="metastoreId")
    def metastore_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the metastore.
        """
        return pulumi.get(self, "metastore_id")

    @metastore_id.setter
    def metastore_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metastore_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of metastore.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username/groupname/sp application_id of the metastore owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="privilegeModelVersion")
    def privilege_model_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        """
        return pulumi.get(self, "privilege_model_version")

    @privilege_model_version.setter
    def privilege_model_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privilege_model_version", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region of the metastore
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        """
        return pulumi.get(self, "storage_root")

    @storage_root.setter
    def storage_root(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root", value)

    @_builtins.property
    @pulumi.getter(name="storageRootCredentialId")
    def storage_root_credential_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional) UUID of storage credential to access the metastore storage_root.
        """
        return pulumi.get(self, "storage_root_credential_id")

    @storage_root_credential_id.setter
    def storage_root_credential_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root_credential_id", value)

    @_builtins.property
    @pulumi.getter(name="storageRootCredentialName")
    def storage_root_credential_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the storage credential to access the metastore storage_root.
        """
        return pulumi.get(self, "storage_root_credential_name")

    @storage_root_credential_name.setter
    def storage_root_credential_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_root_credential_name", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time at which the metastore was last modified, in epoch milliseconds.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username of user who last modified the metastore.
        """
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_by", value)


@pulumi.type_token("databricks:index/metastore:Metastore")
class Metastore(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_data_access_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_recipient_token_lifetime_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 delta_sharing_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 external_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege_model_version: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        > This resource can be used with an account or workspace-level provider.

        A metastore is the top-level container of objects in Unity Catalog. It stores data assets (tables and views) and the permissions that govern access to them. Databricks account admins can create metastores and assign them to Databricks workspaces in order to control which workloads use each metastore.

        Unity Catalog offers a new metastore with built in security and auditing. This is distinct to the metastore used in previous versions of Databricks (based on the Hive Metastore).

        A Unity Catalog metastore can be created without a root location & credential to maintain strict separation of storage across catalogs or environments.

        ## Example Usage

        For AWS

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Metastore("this",
            name="primary",
            storage_root=f"s3://{metastore['id']}/metastore",
            owner="uc admins",
            region="us-east-1",
            force_destroy=True)
        this_metastore_assignment = databricks.MetastoreAssignment("this",
            metastore_id=this.id,
            workspace_id=workspace_id)
        ```

        For Azure

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        this = databricks.Metastore("this",
            name="primary",
            storage_root=std.format(input="abfss://%s@%s.dfs.core.windows.net/",
                args=[
                    unity_catalog["name"],
                    unity_catalog_azurerm_storage_account["name"],
                ]).result,
            owner="uc admins",
            region="eastus",
            force_destroy=True)
        this_metastore_assignment = databricks.MetastoreAssignment("this",
            metastore_id=this.id,
            workspace_id=workspace_id)
        ```

        For GCP

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Metastore("this",
            name="primary",
            storage_root=f"gs://{unity_metastore['name']}",
            owner="uc admins",
            region=us_east1,
            force_destroy=True)
        this_metastore_assignment = databricks.MetastoreAssignment("this",
            metastore_id=this.id,
            workspace_id=workspace_id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] default_data_access_config_id: (Optional) Unique identifier of the metastore's default data access configuration.
        :param pulumi.Input[_builtins.str] delta_sharing_organization_name: The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        :param pulumi.Input[_builtins.int] delta_sharing_recipient_token_lifetime_in_seconds: Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        :param pulumi.Input[_builtins.str] delta_sharing_scope: Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        :param pulumi.Input[_builtins.bool] external_access_enabled: Whether to allow non-DBR clients to directly access entities under the metastore.
        :param pulumi.Input[_builtins.bool] force_destroy: Destroy metastore regardless of its contents.
        :param pulumi.Input[_builtins.str] name: Name of metastore.
        :param pulumi.Input[_builtins.str] owner: Username/groupname/sp application_id of the metastore owner.
        :param pulumi.Input[_builtins.str] privilege_model_version: Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        :param pulumi.Input[_builtins.str] region: The region of the metastore
        :param pulumi.Input[_builtins.str] storage_root: Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        :param pulumi.Input[_builtins.str] storage_root_credential_id: (Optional) UUID of storage credential to access the metastore storage_root.
        :param pulumi.Input[_builtins.str] storage_root_credential_name: Name of the storage credential to access the metastore storage_root.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[MetastoreArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > This resource can be used with an account or workspace-level provider.

        A metastore is the top-level container of objects in Unity Catalog. It stores data assets (tables and views) and the permissions that govern access to them. Databricks account admins can create metastores and assign them to Databricks workspaces in order to control which workloads use each metastore.

        Unity Catalog offers a new metastore with built in security and auditing. This is distinct to the metastore used in previous versions of Databricks (based on the Hive Metastore).

        A Unity Catalog metastore can be created without a root location & credential to maintain strict separation of storage across catalogs or environments.

        ## Example Usage

        For AWS

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Metastore("this",
            name="primary",
            storage_root=f"s3://{metastore['id']}/metastore",
            owner="uc admins",
            region="us-east-1",
            force_destroy=True)
        this_metastore_assignment = databricks.MetastoreAssignment("this",
            metastore_id=this.id,
            workspace_id=workspace_id)
        ```

        For Azure

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        this = databricks.Metastore("this",
            name="primary",
            storage_root=std.format(input="abfss://%s@%s.dfs.core.windows.net/",
                args=[
                    unity_catalog["name"],
                    unity_catalog_azurerm_storage_account["name"],
                ]).result,
            owner="uc admins",
            region="eastus",
            force_destroy=True)
        this_metastore_assignment = databricks.MetastoreAssignment("this",
            metastore_id=this.id,
            workspace_id=workspace_id)
        ```

        For GCP

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Metastore("this",
            name="primary",
            storage_root=f"gs://{unity_metastore['name']}",
            owner="uc admins",
            region=us_east1,
            force_destroy=True)
        this_metastore_assignment = databricks.MetastoreAssignment("this",
            metastore_id=this.id,
            workspace_id=workspace_id)
        ```

        :param str resource_name: The name of the resource.
        :param MetastoreArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MetastoreArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_data_access_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 delta_sharing_recipient_token_lifetime_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 delta_sharing_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 external_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege_model_version: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_root_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MetastoreArgs.__new__(MetastoreArgs)

            __props__.__dict__["default_data_access_config_id"] = default_data_access_config_id
            __props__.__dict__["delta_sharing_organization_name"] = delta_sharing_organization_name
            __props__.__dict__["delta_sharing_recipient_token_lifetime_in_seconds"] = delta_sharing_recipient_token_lifetime_in_seconds
            __props__.__dict__["delta_sharing_scope"] = delta_sharing_scope
            __props__.__dict__["external_access_enabled"] = external_access_enabled
            __props__.__dict__["force_destroy"] = force_destroy
            __props__.__dict__["name"] = name
            __props__.__dict__["owner"] = owner
            __props__.__dict__["privilege_model_version"] = privilege_model_version
            __props__.__dict__["region"] = region
            __props__.__dict__["storage_root"] = storage_root
            __props__.__dict__["storage_root_credential_id"] = storage_root_credential_id
            __props__.__dict__["storage_root_credential_name"] = storage_root_credential_name
            __props__.__dict__["cloud"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["global_metastore_id"] = None
            __props__.__dict__["metastore_id"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["updated_by"] = None
        super(Metastore, __self__).__init__(
            'databricks:index/metastore:Metastore',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.int]] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            default_data_access_config_id: Optional[pulumi.Input[_builtins.str]] = None,
            delta_sharing_organization_name: Optional[pulumi.Input[_builtins.str]] = None,
            delta_sharing_recipient_token_lifetime_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            delta_sharing_scope: Optional[pulumi.Input[_builtins.str]] = None,
            external_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            global_metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
            metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            privilege_model_version: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            storage_root: Optional[pulumi.Input[_builtins.str]] = None,
            storage_root_credential_id: Optional[pulumi.Input[_builtins.str]] = None,
            storage_root_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.int]] = None,
            updated_by: Optional[pulumi.Input[_builtins.str]] = None) -> 'Metastore':
        """
        Get an existing Metastore resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud: Cloud vendor of the metastore home shard (e.g., `aws`, `azure`, `gcp`).
        :param pulumi.Input[_builtins.int] created_at: Time at which the metastore was created, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] created_by: Username of metastore creator.
        :param pulumi.Input[_builtins.str] default_data_access_config_id: (Optional) Unique identifier of the metastore's default data access configuration.
        :param pulumi.Input[_builtins.str] delta_sharing_organization_name: The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        :param pulumi.Input[_builtins.int] delta_sharing_recipient_token_lifetime_in_seconds: Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        :param pulumi.Input[_builtins.str] delta_sharing_scope: Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        :param pulumi.Input[_builtins.bool] external_access_enabled: Whether to allow non-DBR clients to directly access entities under the metastore.
        :param pulumi.Input[_builtins.bool] force_destroy: Destroy metastore regardless of its contents.
        :param pulumi.Input[_builtins.str] global_metastore_id: Globally unique metastore ID across clouds and regions, of the form `cloud:region:metastore_id`.
        :param pulumi.Input[_builtins.str] metastore_id: Unique identifier of the metastore.
        :param pulumi.Input[_builtins.str] name: Name of metastore.
        :param pulumi.Input[_builtins.str] owner: Username/groupname/sp application_id of the metastore owner.
        :param pulumi.Input[_builtins.str] privilege_model_version: Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        :param pulumi.Input[_builtins.str] region: The region of the metastore
        :param pulumi.Input[_builtins.str] storage_root: Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        :param pulumi.Input[_builtins.str] storage_root_credential_id: (Optional) UUID of storage credential to access the metastore storage_root.
        :param pulumi.Input[_builtins.str] storage_root_credential_name: Name of the storage credential to access the metastore storage_root.
        :param pulumi.Input[_builtins.int] updated_at: Time at which the metastore was last modified, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] updated_by: Username of user who last modified the metastore.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MetastoreState.__new__(_MetastoreState)

        __props__.__dict__["cloud"] = cloud
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["default_data_access_config_id"] = default_data_access_config_id
        __props__.__dict__["delta_sharing_organization_name"] = delta_sharing_organization_name
        __props__.__dict__["delta_sharing_recipient_token_lifetime_in_seconds"] = delta_sharing_recipient_token_lifetime_in_seconds
        __props__.__dict__["delta_sharing_scope"] = delta_sharing_scope
        __props__.__dict__["external_access_enabled"] = external_access_enabled
        __props__.__dict__["force_destroy"] = force_destroy
        __props__.__dict__["global_metastore_id"] = global_metastore_id
        __props__.__dict__["metastore_id"] = metastore_id
        __props__.__dict__["name"] = name
        __props__.__dict__["owner"] = owner
        __props__.__dict__["privilege_model_version"] = privilege_model_version
        __props__.__dict__["region"] = region
        __props__.__dict__["storage_root"] = storage_root
        __props__.__dict__["storage_root_credential_id"] = storage_root_credential_id
        __props__.__dict__["storage_root_credential_name"] = storage_root_credential_name
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["updated_by"] = updated_by
        return Metastore(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Output[_builtins.str]:
        """
        Cloud vendor of the metastore home shard (e.g., `aws`, `azure`, `gcp`).
        """
        return pulumi.get(self, "cloud")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.int]:
        """
        Time at which the metastore was created, in epoch milliseconds.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        Username of metastore creator.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="defaultDataAccessConfigId")
    def default_data_access_config_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Optional) Unique identifier of the metastore's default data access configuration.
        """
        return pulumi.get(self, "default_data_access_config_id")

    @_builtins.property
    @pulumi.getter(name="deltaSharingOrganizationName")
    def delta_sharing_organization_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The organization name of a Delta Sharing entity. This field is used for Databricks to Databricks sharing. Once this is set it cannot be removed and can only be modified to another valid value. To delete this value please taint and recreate the resource.
        """
        return pulumi.get(self, "delta_sharing_organization_name")

    @_builtins.property
    @pulumi.getter(name="deltaSharingRecipientTokenLifetimeInSeconds")
    def delta_sharing_recipient_token_lifetime_in_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Required along with `delta_sharing_scope`. Used to set expiration duration in seconds on recipient data access tokens. Defaults to 31536000 (1 year).
        """
        return pulumi.get(self, "delta_sharing_recipient_token_lifetime_in_seconds")

    @_builtins.property
    @pulumi.getter(name="deltaSharingScope")
    def delta_sharing_scope(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Required along with `delta_sharing_recipient_token_lifetime_in_seconds`. Used to enable delta sharing on the metastore. Valid values: `INTERNAL`, `INTERNAL_AND_EXTERNAL`.  `INTERNAL` only allows sharing within the same account, and `INTERNAL_AND_EXTERNAL` allows cross account sharing and token based sharing.
        """
        return pulumi.get(self, "delta_sharing_scope")

    @_builtins.property
    @pulumi.getter(name="externalAccessEnabled")
    def external_access_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to allow non-DBR clients to directly access entities under the metastore.
        """
        return pulumi.get(self, "external_access_enabled")

    @_builtins.property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Destroy metastore regardless of its contents.
        """
        return pulumi.get(self, "force_destroy")

    @_builtins.property
    @pulumi.getter(name="globalMetastoreId")
    def global_metastore_id(self) -> pulumi.Output[_builtins.str]:
        """
        Globally unique metastore ID across clouds and regions, of the form `cloud:region:metastore_id`.
        """
        return pulumi.get(self, "global_metastore_id")

    @_builtins.property
    @pulumi.getter(name="metastoreId")
    def metastore_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the metastore.
        """
        return pulumi.get(self, "metastore_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of metastore.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[_builtins.str]:
        """
        Username/groupname/sp application_id of the metastore owner.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="privilegeModelVersion")
    def privilege_model_version(self) -> pulumi.Output[_builtins.str]:
        """
        Privilege model version of the metastore, of the form `major.minor` (e.g., `1.0`).
        """
        return pulumi.get(self, "privilege_model_version")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region of the metastore
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path on cloud storage account, where managed `Table` are stored.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource. If no `storage_root` is defined for the metastore, each catalog must have a `storage_root` defined.  **It's recommended to define `storage_root` on the catalog level.
        """
        return pulumi.get(self, "storage_root")

    @_builtins.property
    @pulumi.getter(name="storageRootCredentialId")
    def storage_root_credential_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Optional) UUID of storage credential to access the metastore storage_root.
        """
        return pulumi.get(self, "storage_root_credential_id")

    @_builtins.property
    @pulumi.getter(name="storageRootCredentialName")
    def storage_root_credential_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the storage credential to access the metastore storage_root.
        """
        return pulumi.get(self, "storage_root_credential_name")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.int]:
        """
        Time at which the metastore was last modified, in epoch milliseconds.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        Username of user who last modified the metastore.
        """
        return pulumi.get(self, "updated_by")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRfaAccessRequestDestinationsResult',
    'AwaitableGetRfaAccessRequestDestinationsResult',
    'get_rfa_access_request_destinations',
    'get_rfa_access_request_destinations_output',
]

@pulumi.output_type
class GetRfaAccessRequestDestinationsResult:
    """
    A collection of values returned by getRfaAccessRequestDestinations.
    """
    def __init__(__self__, are_any_destinations_hidden=None, destination_source_securable=None, destinations=None, full_name=None, id=None, provider_config=None, securable=None, securable_type=None):
        if are_any_destinations_hidden and not isinstance(are_any_destinations_hidden, bool):
            raise TypeError("Expected argument 'are_any_destinations_hidden' to be a bool")
        pulumi.set(__self__, "are_any_destinations_hidden", are_any_destinations_hidden)
        if destination_source_securable and not isinstance(destination_source_securable, dict):
            raise TypeError("Expected argument 'destination_source_securable' to be a dict")
        pulumi.set(__self__, "destination_source_securable", destination_source_securable)
        if destinations and not isinstance(destinations, list):
            raise TypeError("Expected argument 'destinations' to be a list")
        pulumi.set(__self__, "destinations", destinations)
        if full_name and not isinstance(full_name, str):
            raise TypeError("Expected argument 'full_name' to be a str")
        pulumi.set(__self__, "full_name", full_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if securable and not isinstance(securable, dict):
            raise TypeError("Expected argument 'securable' to be a dict")
        pulumi.set(__self__, "securable", securable)
        if securable_type and not isinstance(securable_type, str):
            raise TypeError("Expected argument 'securable_type' to be a str")
        pulumi.set(__self__, "securable_type", securable_type)

    @_builtins.property
    @pulumi.getter(name="areAnyDestinationsHidden")
    def are_any_destinations_hidden(self) -> _builtins.bool:
        """
        (boolean) - Indicates whether any destinations are hidden from the caller due to a lack of permissions.
        This value is true if the caller does not have permission to see all destinations
        """
        return pulumi.get(self, "are_any_destinations_hidden")

    @_builtins.property
    @pulumi.getter(name="destinationSourceSecurable")
    def destination_source_securable(self) -> 'outputs.GetRfaAccessRequestDestinationsDestinationSourceSecurableResult':
        """
        (Securable) - The source securable from which the destinations are inherited. Either the same value as securable (if destination
        is set directly on the securable) or the nearest parent securable with destinations set
        """
        return pulumi.get(self, "destination_source_securable")

    @_builtins.property
    @pulumi.getter
    def destinations(self) -> Sequence['outputs.GetRfaAccessRequestDestinationsDestinationResult']:
        """
        (list of NotificationDestination) - The access request destinations for the securable
        """
        return pulumi.get(self, "destinations")

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> _builtins.str:
        """
        (string) - Required. The full name of the catalog/schema/table.
        Optional if resource_name is present
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetRfaAccessRequestDestinationsProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def securable(self) -> 'outputs.GetRfaAccessRequestDestinationsSecurableResult':
        """
        (Securable) - The securable for which the access request destinations are being modified or read
        """
        return pulumi.get(self, "securable")

    @_builtins.property
    @pulumi.getter(name="securableType")
    def securable_type(self) -> _builtins.str:
        """
        (string) - The type of the securable. Redundant with the type in the securable object, but necessary for Pulumi integration
        """
        return pulumi.get(self, "securable_type")


class AwaitableGetRfaAccessRequestDestinationsResult(GetRfaAccessRequestDestinationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRfaAccessRequestDestinationsResult(
            are_any_destinations_hidden=self.are_any_destinations_hidden,
            destination_source_securable=self.destination_source_securable,
            destinations=self.destinations,
            full_name=self.full_name,
            id=self.id,
            provider_config=self.provider_config,
            securable=self.securable,
            securable_type=self.securable_type)


def get_rfa_access_request_destinations(full_name: Optional[_builtins.str] = None,
                                        provider_config: Optional[Union['GetRfaAccessRequestDestinationsProviderConfigArgs', 'GetRfaAccessRequestDestinationsProviderConfigArgsDict']] = None,
                                        securable_type: Optional[_builtins.str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRfaAccessRequestDestinationsResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get the Request for Access (RFA) access request destinations for a specific securable object.

    ## Example Usage

    Referring to RFA access request destinations by securable type and full name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    customer_data_schema = databricks.get_rfa_access_request_destinations(securable_type="SCHEMA",
        full_name="main.customer_data")
    ```


    :param _builtins.str full_name: The full name of the securable. Redundant with the name in the securable object, but necessary for Pulumi integration
    :param Union['GetRfaAccessRequestDestinationsProviderConfigArgs', 'GetRfaAccessRequestDestinationsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    :param _builtins.str securable_type: The type of the securable. Redundant with the type in the securable object, but necessary for Pulumi integration
    """
    __args__ = dict()
    __args__['fullName'] = full_name
    __args__['providerConfig'] = provider_config
    __args__['securableType'] = securable_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getRfaAccessRequestDestinations:getRfaAccessRequestDestinations', __args__, opts=opts, typ=GetRfaAccessRequestDestinationsResult).value

    return AwaitableGetRfaAccessRequestDestinationsResult(
        are_any_destinations_hidden=pulumi.get(__ret__, 'are_any_destinations_hidden'),
        destination_source_securable=pulumi.get(__ret__, 'destination_source_securable'),
        destinations=pulumi.get(__ret__, 'destinations'),
        full_name=pulumi.get(__ret__, 'full_name'),
        id=pulumi.get(__ret__, 'id'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        securable=pulumi.get(__ret__, 'securable'),
        securable_type=pulumi.get(__ret__, 'securable_type'))
def get_rfa_access_request_destinations_output(full_name: Optional[pulumi.Input[_builtins.str]] = None,
                                               provider_config: Optional[pulumi.Input[Optional[Union['GetRfaAccessRequestDestinationsProviderConfigArgs', 'GetRfaAccessRequestDestinationsProviderConfigArgsDict']]]] = None,
                                               securable_type: Optional[pulumi.Input[_builtins.str]] = None,
                                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRfaAccessRequestDestinationsResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get the Request for Access (RFA) access request destinations for a specific securable object.

    ## Example Usage

    Referring to RFA access request destinations by securable type and full name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    customer_data_schema = databricks.get_rfa_access_request_destinations(securable_type="SCHEMA",
        full_name="main.customer_data")
    ```


    :param _builtins.str full_name: The full name of the securable. Redundant with the name in the securable object, but necessary for Pulumi integration
    :param Union['GetRfaAccessRequestDestinationsProviderConfigArgs', 'GetRfaAccessRequestDestinationsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    :param _builtins.str securable_type: The type of the securable. Redundant with the type in the securable object, but necessary for Pulumi integration
    """
    __args__ = dict()
    __args__['fullName'] = full_name
    __args__['providerConfig'] = provider_config
    __args__['securableType'] = securable_type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getRfaAccessRequestDestinations:getRfaAccessRequestDestinations', __args__, opts=opts, typ=GetRfaAccessRequestDestinationsResult)
    return __ret__.apply(lambda __response__: GetRfaAccessRequestDestinationsResult(
        are_any_destinations_hidden=pulumi.get(__response__, 'are_any_destinations_hidden'),
        destination_source_securable=pulumi.get(__response__, 'destination_source_securable'),
        destinations=pulumi.get(__response__, 'destinations'),
        full_name=pulumi.get(__response__, 'full_name'),
        id=pulumi.get(__response__, 'id'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        securable=pulumi.get(__response__, 'securable'),
        securable_type=pulumi.get(__response__, 'securable_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, acl_principal_id=None, allow_cluster_create=None, allow_instance_pool_create=None, child_groups=None, databricks_sql_access=None, display_name=None, external_id=None, groups=None, id=None, instance_profiles=None, members=None, provider_config=None, recursive=None, service_principals=None, users=None, workspace_access=None, workspace_consume=None):
        if acl_principal_id and not isinstance(acl_principal_id, str):
            raise TypeError("Expected argument 'acl_principal_id' to be a str")
        pulumi.set(__self__, "acl_principal_id", acl_principal_id)
        if allow_cluster_create and not isinstance(allow_cluster_create, bool):
            raise TypeError("Expected argument 'allow_cluster_create' to be a bool")
        pulumi.set(__self__, "allow_cluster_create", allow_cluster_create)
        if allow_instance_pool_create and not isinstance(allow_instance_pool_create, bool):
            raise TypeError("Expected argument 'allow_instance_pool_create' to be a bool")
        pulumi.set(__self__, "allow_instance_pool_create", allow_instance_pool_create)
        if child_groups and not isinstance(child_groups, list):
            raise TypeError("Expected argument 'child_groups' to be a list")
        pulumi.set(__self__, "child_groups", child_groups)
        if databricks_sql_access and not isinstance(databricks_sql_access, bool):
            raise TypeError("Expected argument 'databricks_sql_access' to be a bool")
        pulumi.set(__self__, "databricks_sql_access", databricks_sql_access)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_profiles and not isinstance(instance_profiles, list):
            raise TypeError("Expected argument 'instance_profiles' to be a list")
        pulumi.set(__self__, "instance_profiles", instance_profiles)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if recursive and not isinstance(recursive, bool):
            raise TypeError("Expected argument 'recursive' to be a bool")
        pulumi.set(__self__, "recursive", recursive)
        if service_principals and not isinstance(service_principals, list):
            raise TypeError("Expected argument 'service_principals' to be a list")
        pulumi.set(__self__, "service_principals", service_principals)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)
        if workspace_access and not isinstance(workspace_access, bool):
            raise TypeError("Expected argument 'workspace_access' to be a bool")
        pulumi.set(__self__, "workspace_access", workspace_access)
        if workspace_consume and not isinstance(workspace_consume, bool):
            raise TypeError("Expected argument 'workspace_consume' to be a bool")
        pulumi.set(__self__, "workspace_consume", workspace_consume)

    @_builtins.property
    @pulumi.getter(name="aclPrincipalId")
    def acl_principal_id(self) -> _builtins.str:
        """
        identifier for use in databricks_access_control_rule_set, e.g. `groups/Some Group`.
        """
        return pulumi.get(self, "acl_principal_id")

    @_builtins.property
    @pulumi.getter(name="allowClusterCreate")
    def allow_cluster_create(self) -> Optional[_builtins.bool]:
        """
        True if group members can create clusters
        """
        return pulumi.get(self, "allow_cluster_create")

    @_builtins.property
    @pulumi.getter(name="allowInstancePoolCreate")
    def allow_instance_pool_create(self) -> Optional[_builtins.bool]:
        """
        True if group members can create instance pools
        """
        return pulumi.get(self, "allow_instance_pool_create")

    @_builtins.property
    @pulumi.getter(name="childGroups")
    def child_groups(self) -> Sequence[_builtins.str]:
        """
        Set of Group identifiers, that can be modified with GroupMember resource.
        """
        return pulumi.get(self, "child_groups")

    @_builtins.property
    @pulumi.getter(name="databricksSqlAccess")
    def databricks_sql_access(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "databricks_sql_access")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="externalId")
    def external_id(self) -> _builtins.str:
        """
        ID of the group in an external identity provider.
        """
        return pulumi.get(self, "external_id")

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Sequence[_builtins.str]:
        """
        Set of group identifiers, that can be modified with GroupMember resource.
        """
        return pulumi.get(self, "groups")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceProfiles")
    def instance_profiles(self) -> Sequence[_builtins.str]:
        """
        Set of instance profile ARNs, that can be modified by GroupInstanceProfile resource.
        """
        return pulumi.get(self, "instance_profiles")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Please use `users`, `service_principals`, and `child_groups` instead""")
    def members(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetGroupProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def recursive(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "recursive")

    @_builtins.property
    @pulumi.getter(name="servicePrincipals")
    def service_principals(self) -> Sequence[_builtins.str]:
        """
        Set of ServicePrincipal identifiers, that can be modified with GroupMember resource.
        """
        return pulumi.get(self, "service_principals")

    @_builtins.property
    @pulumi.getter
    def users(self) -> Sequence[_builtins.str]:
        """
        Set of User identifiers, that can be modified with GroupMember resource.
        """
        return pulumi.get(self, "users")

    @_builtins.property
    @pulumi.getter(name="workspaceAccess")
    def workspace_access(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "workspace_access")

    @_builtins.property
    @pulumi.getter(name="workspaceConsume")
    def workspace_consume(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "workspace_consume")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            acl_principal_id=self.acl_principal_id,
            allow_cluster_create=self.allow_cluster_create,
            allow_instance_pool_create=self.allow_instance_pool_create,
            child_groups=self.child_groups,
            databricks_sql_access=self.databricks_sql_access,
            display_name=self.display_name,
            external_id=self.external_id,
            groups=self.groups,
            id=self.id,
            instance_profiles=self.instance_profiles,
            members=self.members,
            provider_config=self.provider_config,
            recursive=self.recursive,
            service_principals=self.service_principals,
            users=self.users,
            workspace_access=self.workspace_access,
            workspace_consume=self.workspace_consume)


def get_group(acl_principal_id: Optional[_builtins.str] = None,
              allow_cluster_create: Optional[_builtins.bool] = None,
              allow_instance_pool_create: Optional[_builtins.bool] = None,
              child_groups: Optional[Sequence[_builtins.str]] = None,
              databricks_sql_access: Optional[_builtins.bool] = None,
              display_name: Optional[_builtins.str] = None,
              external_id: Optional[_builtins.str] = None,
              groups: Optional[Sequence[_builtins.str]] = None,
              instance_profiles: Optional[Sequence[_builtins.str]] = None,
              members: Optional[Sequence[_builtins.str]] = None,
              provider_config: Optional[Union['GetGroupProviderConfigArgs', 'GetGroupProviderConfigArgsDict']] = None,
              recursive: Optional[_builtins.bool] = None,
              service_principals: Optional[Sequence[_builtins.str]] = None,
              users: Optional[Sequence[_builtins.str]] = None,
              workspace_access: Optional[_builtins.bool] = None,
              workspace_consume: Optional[_builtins.bool] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    Retrieves information about Group members, entitlements and instance profiles.

    > This data source can be used with an account or workspace-level provider.

    ## Example Usage

    Adding user to administrative group

    ```python
    import pulumi
    import pulumi_databricks as databricks

    admins = databricks.get_group(display_name="admins")
    me = databricks.User("me", user_name="me@example.com")
    my_member_a = databricks.GroupMember("my_member_a",
        group_id=admins.id,
        member_id=me.id)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * End to end workspace management guide
    * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
    * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).
    * GroupMember to attach users and groups as group members.
    * Permissions to manage [access control](https://docs.databricks.com/security/access-control/index.html) in Databricks workspace.
    * User to [manage users](https://docs.databricks.com/administration-guide/users-groups/users.html), that could be added to Group within the workspace.


    :param _builtins.str acl_principal_id: identifier for use in databricks_access_control_rule_set, e.g. `groups/Some Group`.
    :param _builtins.bool allow_cluster_create: True if group members can create clusters
    :param _builtins.bool allow_instance_pool_create: True if group members can create instance pools
    :param Sequence[_builtins.str] child_groups: Set of Group identifiers, that can be modified with GroupMember resource.
    :param _builtins.str display_name: Display name of the group. The group must exist before this resource can be planned.
    :param _builtins.str external_id: ID of the group in an external identity provider.
    :param Sequence[_builtins.str] groups: Set of group identifiers, that can be modified with GroupMember resource.
    :param Sequence[_builtins.str] instance_profiles: Set of instance profile ARNs, that can be modified by GroupInstanceProfile resource.
    :param Union['GetGroupProviderConfigArgs', 'GetGroupProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    :param _builtins.bool recursive: Collect information for all nested groups. *Defaults to true.*
    :param Sequence[_builtins.str] service_principals: Set of ServicePrincipal identifiers, that can be modified with GroupMember resource.
    :param Sequence[_builtins.str] users: Set of User identifiers, that can be modified with GroupMember resource.
    """
    __args__ = dict()
    __args__['aclPrincipalId'] = acl_principal_id
    __args__['allowClusterCreate'] = allow_cluster_create
    __args__['allowInstancePoolCreate'] = allow_instance_pool_create
    __args__['childGroups'] = child_groups
    __args__['databricksSqlAccess'] = databricks_sql_access
    __args__['displayName'] = display_name
    __args__['externalId'] = external_id
    __args__['groups'] = groups
    __args__['instanceProfiles'] = instance_profiles
    __args__['members'] = members
    __args__['providerConfig'] = provider_config
    __args__['recursive'] = recursive
    __args__['servicePrincipals'] = service_principals
    __args__['users'] = users
    __args__['workspaceAccess'] = workspace_access
    __args__['workspaceConsume'] = workspace_consume
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        acl_principal_id=pulumi.get(__ret__, 'acl_principal_id'),
        allow_cluster_create=pulumi.get(__ret__, 'allow_cluster_create'),
        allow_instance_pool_create=pulumi.get(__ret__, 'allow_instance_pool_create'),
        child_groups=pulumi.get(__ret__, 'child_groups'),
        databricks_sql_access=pulumi.get(__ret__, 'databricks_sql_access'),
        display_name=pulumi.get(__ret__, 'display_name'),
        external_id=pulumi.get(__ret__, 'external_id'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        instance_profiles=pulumi.get(__ret__, 'instance_profiles'),
        members=pulumi.get(__ret__, 'members'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        recursive=pulumi.get(__ret__, 'recursive'),
        service_principals=pulumi.get(__ret__, 'service_principals'),
        users=pulumi.get(__ret__, 'users'),
        workspace_access=pulumi.get(__ret__, 'workspace_access'),
        workspace_consume=pulumi.get(__ret__, 'workspace_consume'))
def get_group_output(acl_principal_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     allow_cluster_create: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     allow_instance_pool_create: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     child_groups: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                     databricks_sql_access: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     display_name: Optional[pulumi.Input[_builtins.str]] = None,
                     external_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     groups: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                     instance_profiles: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                     members: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                     provider_config: Optional[pulumi.Input[Optional[Union['GetGroupProviderConfigArgs', 'GetGroupProviderConfigArgsDict']]]] = None,
                     recursive: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     service_principals: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                     users: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                     workspace_access: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     workspace_consume: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    Retrieves information about Group members, entitlements and instance profiles.

    > This data source can be used with an account or workspace-level provider.

    ## Example Usage

    Adding user to administrative group

    ```python
    import pulumi
    import pulumi_databricks as databricks

    admins = databricks.get_group(display_name="admins")
    me = databricks.User("me", user_name="me@example.com")
    my_member_a = databricks.GroupMember("my_member_a",
        group_id=admins.id,
        member_id=me.id)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * End to end workspace management guide
    * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
    * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).
    * GroupMember to attach users and groups as group members.
    * Permissions to manage [access control](https://docs.databricks.com/security/access-control/index.html) in Databricks workspace.
    * User to [manage users](https://docs.databricks.com/administration-guide/users-groups/users.html), that could be added to Group within the workspace.


    :param _builtins.str acl_principal_id: identifier for use in databricks_access_control_rule_set, e.g. `groups/Some Group`.
    :param _builtins.bool allow_cluster_create: True if group members can create clusters
    :param _builtins.bool allow_instance_pool_create: True if group members can create instance pools
    :param Sequence[_builtins.str] child_groups: Set of Group identifiers, that can be modified with GroupMember resource.
    :param _builtins.str display_name: Display name of the group. The group must exist before this resource can be planned.
    :param _builtins.str external_id: ID of the group in an external identity provider.
    :param Sequence[_builtins.str] groups: Set of group identifiers, that can be modified with GroupMember resource.
    :param Sequence[_builtins.str] instance_profiles: Set of instance profile ARNs, that can be modified by GroupInstanceProfile resource.
    :param Union['GetGroupProviderConfigArgs', 'GetGroupProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    :param _builtins.bool recursive: Collect information for all nested groups. *Defaults to true.*
    :param Sequence[_builtins.str] service_principals: Set of ServicePrincipal identifiers, that can be modified with GroupMember resource.
    :param Sequence[_builtins.str] users: Set of User identifiers, that can be modified with GroupMember resource.
    """
    __args__ = dict()
    __args__['aclPrincipalId'] = acl_principal_id
    __args__['allowClusterCreate'] = allow_cluster_create
    __args__['allowInstancePoolCreate'] = allow_instance_pool_create
    __args__['childGroups'] = child_groups
    __args__['databricksSqlAccess'] = databricks_sql_access
    __args__['displayName'] = display_name
    __args__['externalId'] = external_id
    __args__['groups'] = groups
    __args__['instanceProfiles'] = instance_profiles
    __args__['members'] = members
    __args__['providerConfig'] = provider_config
    __args__['recursive'] = recursive
    __args__['servicePrincipals'] = service_principals
    __args__['users'] = users
    __args__['workspaceAccess'] = workspace_access
    __args__['workspaceConsume'] = workspace_consume
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        acl_principal_id=pulumi.get(__response__, 'acl_principal_id'),
        allow_cluster_create=pulumi.get(__response__, 'allow_cluster_create'),
        allow_instance_pool_create=pulumi.get(__response__, 'allow_instance_pool_create'),
        child_groups=pulumi.get(__response__, 'child_groups'),
        databricks_sql_access=pulumi.get(__response__, 'databricks_sql_access'),
        display_name=pulumi.get(__response__, 'display_name'),
        external_id=pulumi.get(__response__, 'external_id'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        instance_profiles=pulumi.get(__response__, 'instance_profiles'),
        members=pulumi.get(__response__, 'members'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        recursive=pulumi.get(__response__, 'recursive'),
        service_principals=pulumi.get(__response__, 'service_principals'),
        users=pulumi.get(__response__, 'users'),
        workspace_access=pulumi.get(__response__, 'workspace_access'),
        workspace_consume=pulumi.get(__response__, 'workspace_consume')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAccountNetworkPolicyResult',
    'AwaitableGetAccountNetworkPolicyResult',
    'get_account_network_policy',
    'get_account_network_policy_output',
]

@pulumi.output_type
class GetAccountNetworkPolicyResult:
    """
    A collection of values returned by getAccountNetworkPolicy.
    """
    def __init__(__self__, account_id=None, egress=None, id=None, network_policy_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if egress and not isinstance(egress, dict):
            raise TypeError("Expected argument 'egress' to be a dict")
        pulumi.set(__self__, "egress", egress)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network_policy_id and not isinstance(network_policy_id, str):
            raise TypeError("Expected argument 'network_policy_id' to be a str")
        pulumi.set(__self__, "network_policy_id", network_policy_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        (string) - The associated account ID for this Network Policy object
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def egress(self) -> 'outputs.GetAccountNetworkPolicyEgressResult':
        """
        (NetworkPolicyEgress) - The network policies applying for egress traffic
        """
        return pulumi.get(self, "egress")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="networkPolicyId")
    def network_policy_id(self) -> _builtins.str:
        """
        (string) - The unique identifier for the network policy
        """
        return pulumi.get(self, "network_policy_id")


class AwaitableGetAccountNetworkPolicyResult(GetAccountNetworkPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountNetworkPolicyResult(
            account_id=self.account_id,
            egress=self.egress,
            id=self.id,
            network_policy_id=self.network_policy_id)


def get_account_network_policy(network_policy_id: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountNetworkPolicyResult:
    """
    [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single network policy.

    > **Note** This data source can only be used with an account-level provider!

    ## Example Usage

    Referring to a network policy by id:


    :param _builtins.str network_policy_id: The unique identifier for the network policy
    """
    __args__ = dict()
    __args__['networkPolicyId'] = network_policy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAccountNetworkPolicy:getAccountNetworkPolicy', __args__, opts=opts, typ=GetAccountNetworkPolicyResult).value

    return AwaitableGetAccountNetworkPolicyResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        egress=pulumi.get(__ret__, 'egress'),
        id=pulumi.get(__ret__, 'id'),
        network_policy_id=pulumi.get(__ret__, 'network_policy_id'))
def get_account_network_policy_output(network_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountNetworkPolicyResult]:
    """
    [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single network policy.

    > **Note** This data source can only be used with an account-level provider!

    ## Example Usage

    Referring to a network policy by id:


    :param _builtins.str network_policy_id: The unique identifier for the network policy
    """
    __args__ = dict()
    __args__['networkPolicyId'] = network_policy_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAccountNetworkPolicy:getAccountNetworkPolicy', __args__, opts=opts, typ=GetAccountNetworkPolicyResult)
    return __ret__.apply(lambda __response__: GetAccountNetworkPolicyResult(
        account_id=pulumi.get(__response__, 'account_id'),
        egress=pulumi.get(__response__, 'egress'),
        id=pulumi.get(__response__, 'id'),
        network_policy_id=pulumi.get(__response__, 'network_policy_id')))
